@@ -38,6 +38,7 @@ from cvxpy.reductions.dgp2dcp.dgp2dcp import Dgp2Dcp
 from cvxpy.reductions.dqcp2dcp import dqcp2dcp
 from cvxpy.reductions.eval_params import EvalParams
 from cvxpy.reductions.flip_objective import FlipObjective
+from cvxpy.reductions.solution import INF_OR_UNB_MESSAGE
 from cvxpy.reductions.solvers import bisection
 from cvxpy.reductions.solvers import defines as slv_def
 from cvxpy.reductions.solvers.conic_solvers.conic_solver import ConicSolver
@@ -721,12 +722,16 @@ class Problem(u.Canonical):
                     for discussion on this topic.
 
                     Quick fix 1: if you install the python package CVXOPT (pip install cvxopt),
-                    then CVXPY can use the open-source mixed-integer solver `GLPK`.
+                    then CVXPY can use the open-source mixed-integer linear programming
+                    solver `GLPK`. If your problem is nonlinear then you can install SCIP
+                    (pip install pyscipopt).
 
                     Quick fix 2: you can explicitly specify solver='ECOS_BB'. This may result
                     in incorrect solutions and is not recommended.
                 """
                 raise error.SolverError(msg)
+            # TODO: provide a useful error message when the problem is nonlinear but
+            #  the only installed mixed-integer solvers are MILP solvers (e.g., GLPK_MI).
             candidates['qp_solvers'] = [
                 s for s in candidates['qp_solvers']
                 if slv_def.SOLVER_MAP_QP[s].MIP_CAPABLE]
@@ -979,7 +984,8 @@ class Problem(u.Canonical):
         if verbose:
             print(_FOOTER)
             s.LOGGER.info('Problem status: %s', self.status)
-            s.LOGGER.info('Optimal value: %.3e', self.value)
+            val = self.value if self.value is not None else np.NaN
+            s.LOGGER.info('Optimal value: %.3e', val)
             s.LOGGER.info('Compilation took %.3e seconds', self._compilation_time)
             s.LOGGER.info(
                     'Solver (including time spent in interface) took '
@@ -1296,6 +1302,8 @@ class Problem(u.Canonical):
                 "adjusting the solver settings, or solve with "
                 "verbose=True for more information."
             )
+        if solution.status == s.INFEASIBLE_OR_UNBOUNDED:
+            warnings.warn(INF_OR_UNB_MESSAGE)
         if solution.status in s.ERROR:
             raise error.SolverError(
                     "Solver '%s' failed. " % chain.solver.name() +
